@@ -4,4 +4,4 @@
 # Copyright (c) 2019-2020 Ingram Micro. All Rights Reserved.
 
 from cnctcli.actions.products.export import dump_product  # noqa: F401
-from cnctcli.actions.products.sync import sync_product, validate_input_file  # noqa: F401
+from cnctcli.actions.products.sync import ProductSynchronizer  # noqa: F401
